# Netlink
This package provides an asynchronous implementation of the Linux netlink protocol, including basic support for nl80211.

This package can be installed using `pip3 install python-netlink` and requires Python 3.9 or later.

Documentation is available [here](https://netlink.readthedocs.io).
